@@ -1,4 +1,4 @@
-/* $Id: gii.h,v 1.4 2002/02/22 21:51:05 soyt Exp $
+/* $Id: gii.h,v 1.10 2004/06/23 10:55:11 pekberg Exp $
 ******************************************************************************
 
    LibGII internals
@@ -46,17 +46,13 @@ typedef struct gii_input  *gii_input_t;
 __BEGIN_DECLS
 
 /* Exported variables */
-#ifdef BUILDING_LIBGII
-extern int                   _gii_threadsafe;
-extern void                 *_gii_global_lock;
-#else
-IMPORTVAR int                _gii_threadsafe;
-IMPORTVAR void              *_gii_global_lock;
-#endif
+GIIAPIVAR int                _gii_threadsafe;
+GIIAPIVAR void              *_gii_global_lock;
 
 /* Global variables */
 extern void                 *_giiconfhandle;
 extern void                 *_gii_safe_lock;
+extern void                 *_gii_event_lock;
 
 __END_DECLS
 
@@ -131,7 +127,7 @@ typedef struct gii_input {
 #define GII_FLAGS_HASPOLLED	0x00000001
 
 #define GII_QUEUE_SIZE      8192
-#define GII_Q_THRESHOLD     (GII_QUEUE_SIZE - sizeof(gii_event) - 1)
+#define GII_Q_THRESHOLD     (GII_QUEUE_SIZE - (int)sizeof(gii_event) - 1)
 
 /* The threshold the point where events wrap back to the start of the
  * buffer.  Events are stored in the buffer in whole; they do not get
@@ -169,26 +165,30 @@ __BEGIN_DECLS
 gii_dlhandle *_giiLoadDL(const char *name, const char *version);
 int _giiCloseDL(gii_dlhandle *hand);
 
-void _giiEventBlank(gii_event *ev, int size);
-int  _giiEvQueueAdd(gii_input *inp, gii_event *ev);
+GIIAPIFUNC void _giiEventBlank(gii_event *ev, size_t size);
+GIIAPIFUNC int  _giiEvQueueAdd(gii_input *inp, gii_event *ev);
+
+int _giiStdSendDevInfo(gii_input *inp, gii_cmddata_getdevinfo *data);
+int _giiStdSendValEvent(gii_input *inp, gii_cmddata_getvalinfo *vi,
+			int val, int maxval);
 
 gii_event_mask _giiPollall(gii_input *inp, gii_event_mask mask, void *arg);
 
 gii_inputchain_cache *_giiCacheAlloc(void);
 void _giiCacheFree(gii_inputchain_cache *cache);
-void _giiUpdateCache(gii_input *inp);
+GIIAPIFUNC void _giiUpdateCache(gii_input *inp);
 
 int _giiSafeAdd(struct gii_input *inp, gii_event *ev);
 int _giiSafeMove(struct gii_input *toinp, struct gii_input *frominp);
 
 void _giiAsyncNotify(gii_input *inp);
 
-uint32 _giiRegisterDevice(gii_input *inp,
-			  gii_cmddata_getdevinfo  *dev,
-			  gii_cmddata_getvalinfo  *val);
+GIIAPIFUNC uint32 _giiRegisterDevice(gii_input *inp,
+				     gii_cmddata_getdevinfo  *dev,
+				     gii_cmddata_getvalinfo  *val);
 
-int              _giiUnregisterDevice(gii_input *inp,
-				      uint32 origin);
+int               _giiUnregisterDevice(gii_input *inp,
+				       uint32 origin);
 
 __END_DECLS
 
